@@ -32,6 +32,8 @@ from pyams_portal.interfaces import IPortalContext, IPortalPage, IPortalPortlets
     IPortalTemplate, IPortalTemplateConfiguration, IPortletAddingInfo, IPortletConfiguration, \
     IPortletPreviewer, IPortletRendererSettings, IPortletSettings, MANAGE_TEMPLATE_PERMISSION
 from pyams_portal.page import check_local_template
+from pyams_portal.portlet import LOGGER
+from pyams_portal.skin import PORTLETS_CACHE_NAME, PORTLETS_CACHE_NAMESPACE, PORTLETS_CACHE_REGION
 from pyams_portal.zmi.interfaces import IPortletConfigurationEditor
 from pyams_portal.zmi.layout import PortalTemplateLayoutView
 from pyams_portal.zmi.widget import PortletRendererFieldWidget
@@ -39,7 +41,9 @@ from pyams_skin.interfaces.viewlet import IHeaderViewletManager
 from pyams_skin.viewlet.help import AlertMessage
 from pyams_skin.viewlet.menu import MenuDivider, MenuItem
 from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
+from pyams_utils.cache import get_cache
 from pyams_utils.dict import merge_dict
+from pyams_utils.traversing import get_parent
 from pyams_utils.url import absolute_url
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zmi.form import AdminModalAddForm, AdminModalEditForm, FormGroupChecker
@@ -118,8 +122,7 @@ class PortalTemplatePortletAddForm(AdminModalAddForm):  # pylint: disable=abstra
         translate = self.request.localizer.translate
         if IPortalTemplate.providedBy(self.context):
             return translate(_("« {} »  portal template")).format(self.context.name)
-        title = IPageTitle(self.context, None)
-        return translate(_("« {} » local template")).format(title or self.context.__name__)
+        return translate(_("Local template"))
 
     legend = _("Add template portlet")
 
@@ -237,7 +240,20 @@ class PortalTemplatePortletEditForm(AdminModalEditForm):
     def title(self):
         """Title getter"""
         translate = self.request.localizer.translate
-        return translate(_("Portlet configuration: {}")).format(translate(self.portlet.label))
+        if IPortalTemplate.providedBy(self.context):
+            title = translate(_("« {} »  portal template")).format(self.context.name)
+        else:
+            context = get_parent(self.context, IPortalContext)
+            page = IPortalPage(context)
+            if page.use_shared_template:
+                title = translate(_("« {} » shared template")).format(page.template.name)
+            else:
+                title = translate(_("Local template"))
+            if page.inherit_parent:
+                title = translate(_("{} (inherited from parent)")).format(title)
+        return '<small>{}</small><br />{}'.format(
+            title,
+            translate(_("Portlet configuration: « {} »")).format(translate(self.portlet.label)))
 
     @property
     def fields(self):
@@ -346,7 +362,7 @@ class PortletConfigurationEditForm(InnerEditForm):
         """Legend getter"""
         if IGroup.providedBy(self.parent_form):
             return None
-        return _("Portlet configuration")
+        return _("Portlet settings")
 
     border_class = ''
 
@@ -368,6 +384,13 @@ class PortletConfigurationEditFormRenderer(AJAXFormRenderer):
         """AJAX form renderer"""
         if not changes:
             return None
+        # clear portlets cache on update
+        LOGGER.debug("Clearing portlets cache...")
+        portlets_cache = get_cache(PORTLETS_CACHE_NAME,
+                                   PORTLETS_CACHE_REGION,
+                                   PORTLETS_CACHE_NAMESPACE)
+        portlets_cache.clear()
+        # return notice on renderer update
         if 'renderer' in changes.get(IPortletSettings, ()):
             result = {}
             renderer = self.context.get_renderer(self.request)
@@ -430,8 +453,8 @@ def delete_template_portlet(request):
 @ajax_form_config(name='renderer-settings.html',
                   context=IPortletSettings, layer=IPyAMSLayer,
                   permission=MANAGE_TEMPLATE_PERMISSION)
-class PortletSettingsEditForm(AdminModalEditForm):
-    """Portlet settings edit form"""
+class PortletRendererSettingsEditForm(AdminModalEditForm):
+    """Portlet renderer settings edit form"""
 
     def __init__(self, context, request):
         super().__init__(context, request)
@@ -441,9 +464,9 @@ class PortletSettingsEditForm(AdminModalEditForm):
     def title(self):
         """Title getter"""
         translate = self.request.localizer.translate
-        return translate(_("{portlet}: « {renderer} » renderer")).format(
-            portlet=translate(self.renderer.portlet.label),
-            renderer=translate(self.renderer.label))
+        return translate(_("<small>Portlet: {portlet}</small><br />« {renderer} » renderer")) \
+            .format(portlet=translate(self.renderer.portlet.label),
+                    renderer=translate(self.renderer.label))
 
     legend = _("Edit renderer settings")
     modal_class = 'modal-xl'
@@ -455,3 +478,24 @@ class PortletSettingsEditForm(AdminModalEditForm):
 
     def get_content(self):
         return IPortletRendererSettings(self.context)
+
+
+@adapter_config(required=(Interface, IAdminLayer, PortletRendererSettingsEditForm),
+                provides=IAJAXFormRenderer)
+class PortletRendererSettingsEditFormRenderer(ContextRequestViewAdapter):
+    """Portlet renderer settings edit form renderer"""
+
+    def render(self, changes):
+        """AJAX form renderer"""
+        if not changes:
+            return None
+        # clear portlets cache on update
+        LOGGER.debug("Clearing portlets cache...")
+        portlets_cache = get_cache(PORTLETS_CACHE_NAME,
+                                   PORTLETS_CACHE_REGION,
+                                   PORTLETS_CACHE_NAMESPACE)
+        portlets_cache.clear()
+        return {
+            'status': 'success',
+            'message': self.request.localizer.translate(self.view.success_message)
+        }
